==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/robomaker/CfnSimulationApplicationVersionProps.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * Properties for defining a `AWS::RoboMaker::SimulationApplicationVersion`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:32.555Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_robomaker.CfnSimulationApplicationVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnSimulationApplicationVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSimulationApplicationVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::RoboMaker::SimulationApplicationVersion.Application`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getApplication();

    /**
     * `AWS::RoboMaker::SimulationApplicationVersion.CurrentRevisionId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCurrentRevisionId() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSimulationApplicationVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSimulationApplicationVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSimulationApplicationVersionProps> {
        private java.lang.String application;
        private java.lang.String currentRevisionId;

        /**
         * Sets the value of {@link CfnSimulationApplicationVersionProps#getApplication}
         * @param application `AWS::RoboMaker::SimulationApplicationVersion.Application`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder application(java.lang.String application) {
            this.application = application;
            return this;
        }

        /**
         * Sets the value of {@link CfnSimulationApplicationVersionProps#getCurrentRevisionId}
         * @param currentRevisionId `AWS::RoboMaker::SimulationApplicationVersion.CurrentRevisionId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder currentRevisionId(java.lang.String currentRevisionId) {
            this.currentRevisionId = currentRevisionId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSimulationApplicationVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSimulationApplicationVersionProps build() {
            return new Jsii$Proxy(application, currentRevisionId);
        }
    }

    /**
     * An implementation for {@link CfnSimulationApplicationVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSimulationApplicationVersionProps {
        private final java.lang.String application;
        private final java.lang.String currentRevisionId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.application = software.amazon.jsii.Kernel.get(this, "application", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.currentRevisionId = software.amazon.jsii.Kernel.get(this, "currentRevisionId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String application, final java.lang.String currentRevisionId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.application = java.util.Objects.requireNonNull(application, "application is required");
            this.currentRevisionId = currentRevisionId;
        }

        @Override
        public final java.lang.String getApplication() {
            return this.application;
        }

        @Override
        public final java.lang.String getCurrentRevisionId() {
            return this.currentRevisionId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("application", om.valueToTree(this.getApplication()));
            if (this.getCurrentRevisionId() != null) {
                data.set("currentRevisionId", om.valueToTree(this.getCurrentRevisionId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_robomaker.CfnSimulationApplicationVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSimulationApplicationVersionProps.Jsii$Proxy that = (CfnSimulationApplicationVersionProps.Jsii$Proxy) o;

            if (!application.equals(that.application)) return false;
            return this.currentRevisionId != null ? this.currentRevisionId.equals(that.currentRevisionId) : that.currentRevisionId == null;
        }

        @Override
        public final int hashCode() {
            int result = this.application.hashCode();
            result = 31 * result + (this.currentRevisionId != null ? this.currentRevisionId.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/robomaker/CfnSimulationApplicationVersionProps.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * Properties for defining a `CfnSimulationApplicationVersion`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.robomaker.*;
 * CfnSimulationApplicationVersionProps cfnSimulationApplicationVersionProps = CfnSimulationApplicationVersionProps.builder()
 *         .application("application")
 *         // the properties below are optional
 *         .currentRevisionId("currentRevisionId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:12.338Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_robomaker.CfnSimulationApplicationVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnSimulationApplicationVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSimulationApplicationVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The application information for the simulation application.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getApplication();

    /**
     * The current revision id for the simulation application.
     * <p>
     * If you provide a value and it matches the latest revision ID, a new version will be created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCurrentRevisionId() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSimulationApplicationVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSimulationApplicationVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSimulationApplicationVersionProps> {
        java.lang.String application;
        java.lang.String currentRevisionId;

        /**
         * Sets the value of {@link CfnSimulationApplicationVersionProps#getApplication}
         * @param application The application information for the simulation application. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder application(java.lang.String application) {
            this.application = application;
            return this;
        }

        /**
         * Sets the value of {@link CfnSimulationApplicationVersionProps#getCurrentRevisionId}
         * @param currentRevisionId The current revision id for the simulation application.
         *                          If you provide a value and it matches the latest revision ID, a new version will be created.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder currentRevisionId(java.lang.String currentRevisionId) {
            this.currentRevisionId = currentRevisionId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSimulationApplicationVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSimulationApplicationVersionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSimulationApplicationVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSimulationApplicationVersionProps {
        private final java.lang.String application;
        private final java.lang.String currentRevisionId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.application = software.amazon.jsii.Kernel.get(this, "application", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.currentRevisionId = software.amazon.jsii.Kernel.get(this, "currentRevisionId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.application = java.util.Objects.requireNonNull(builder.application, "application is required");
            this.currentRevisionId = builder.currentRevisionId;
        }

        @Override
        public final java.lang.String getApplication() {
            return this.application;
        }

        @Override
        public final java.lang.String getCurrentRevisionId() {
            return this.currentRevisionId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("application", om.valueToTree(this.getApplication()));
            if (this.getCurrentRevisionId() != null) {
                data.set("currentRevisionId", om.valueToTree(this.getCurrentRevisionId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_robomaker.CfnSimulationApplicationVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSimulationApplicationVersionProps.Jsii$Proxy that = (CfnSimulationApplicationVersionProps.Jsii$Proxy) o;

            if (!application.equals(that.application)) return false;
            return this.currentRevisionId != null ? this.currentRevisionId.equals(that.currentRevisionId) : that.currentRevisionId == null;
        }

        @Override
        public final int hashCode() {
            int result = this.application.hashCode();
            result = 31 * result + (this.currentRevisionId != null ? this.currentRevisionId.hashCode() : 0);
            return result;
        }
    }
}
